# The Post Editor’s Data

Namespace: `core/editor`.

## Selectors

<!-- START TOKEN(Autogenerated selectors|../../../packages/editor/src/store/selectors.js) -->

### canInsertBlockType

_Related_

-   canInsertBlockType in core/block-editor store.

### canUserUseUnfilteredHTML

Returns whether or not the user has the unfiltered_html capability.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `boolean`: Whether the user can or can't post unfiltered HTML.

### didPostSaveRequestFail

Returns true if a previous post save was attempted but failed, or false
otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the post save failed.

### didPostSaveRequestSucceed

Returns true if a previous post save was attempted successfully, or false
otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the post was saved successfully.

### getActivePostLock

Returns the active post lock.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Object`: The lock object.

### getAdjacentBlockClientId

_Related_

-   getAdjacentBlockClientId in core/block-editor store.

### getAutosave

> **Deprecated** since 5.6. Callers should use the `getAutosave( postType, postId, userId )` selector from the '@wordpress/core-data' package.

Returns the current autosave, or null if one is not set (i.e. if the post
has yet to be autosaved, or has been saved or published since the last
autosave).

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `?Object`: Current autosave, if exists.

### getAutosaveAttribute

> **Deprecated** since 5.6. Callers should use the `getAutosave( postType, postId, userId )` selector from the '@wordpress/core-data' package and access properties on the returned autosave object using getPostRawValue.

Returns an attribute value of the current autosave revision for a post, or
null if there is no autosave for the post.

_Parameters_

-   _state_ `Object`: Global application state.
-   _attributeName_ `string`: Autosave attribute name.

_Returns_

-   `*`: Autosave attribute value.

### getBlock

_Related_

-   getBlock in core/block-editor store.

### getBlockAttributes

_Related_

-   getBlockAttributes in core/block-editor store.

### getBlockCount

_Related_

-   getBlockCount in core/block-editor store.

### getBlockHierarchyRootClientId

_Related_

-   getBlockHierarchyRootClientId in core/block-editor store.

### getBlockIndex

_Related_

-   getBlockIndex in core/block-editor store.

### getBlockInsertionPoint

_Related_

-   getBlockInsertionPoint in core/block-editor store.

### getBlockListSettings

_Related_

-   getBlockListSettings in core/block-editor store.

### getBlockMode

_Related_

-   getBlockMode in core/block-editor store.

### getBlockName

_Related_

-   getBlockName in core/block-editor store.

### getBlockOrder

_Related_

-   getBlockOrder in core/block-editor store.

### getBlockRootClientId

_Related_

-   getBlockRootClientId in core/block-editor store.

### getBlocks

_Related_

-   getBlocks in core/block-editor store.

### getBlocksByClientId

_Related_

-   getBlocksByClientId in core/block-editor store.

### getBlockSelectionEnd

_Related_

-   getBlockSelectionEnd in core/block-editor store.

### getBlockSelectionStart

_Related_

-   getBlockSelectionStart in core/block-editor store.

### getBlocksForSerialization

> **Deprecated** since Gutenberg 6.2.0.

Returns a set of blocks which are to be used in consideration of the post's
generated save content.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `WPBlock[]`: Filtered set of blocks for save.

### getClientIdsOfDescendants

_Related_

-   getClientIdsOfDescendants in core/block-editor store.

### getClientIdsWithDescendants

_Related_

-   getClientIdsWithDescendants in core/block-editor store.

### getCurrentPost

Returns the post currently being edited in its last known saved state, not
including unsaved edits. Returns an object containing relevant default post
values if the post has not yet been saved.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Object`: Post object.

### getCurrentPostAttribute

Returns an attribute value of the saved post.

_Parameters_

-   _state_ `Object`: Global application state.
-   _attributeName_ `string`: Post attribute name.

_Returns_

-   `*`: Post attribute value.

### getCurrentPostId

Returns the ID of the post currently being edited, or null if the post has
not yet been saved.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?number`: ID of current post.

### getCurrentPostLastRevisionId

Returns the last revision ID of the post currently being edited,
or null if the post has no revisions.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?number`: ID of the last revision.

### getCurrentPostRevisionsCount

Returns the number of revisions of the post currently being edited.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `number`: Number of revisions.

### getCurrentPostType

Returns the post type of the post currently being edited.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `string`: Post type.

### getEditedPostAttribute

Returns a single attribute of the post being edited, preferring the unsaved
edit if one exists, but falling back to the attribute for the last known
saved state of the post.

_Parameters_

-   _state_ `Object`: Global application state.
-   _attributeName_ `string`: Post attribute name.

_Returns_

-   `*`: Post attribute value.

### getEditedPostContent

Returns the content of the post being edited.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `string`: Post content.

### getEditedPostPreviewLink

Returns the post preview link

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `string?`: Preview Link.

### getEditedPostSlug

Returns the slug for the post being edited, preferring a manually edited
value if one exists, then a sanitized version of the current post title, and
finally the post ID.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `string`: The current slug to be displayed in the editor

### getEditedPostVisibility

Returns the current visibility of the post being edited, preferring the
unsaved value if different than the saved post. The return value is one of
"private", "password", or "public".

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `string`: Post visibility.

### getEditorBlocks

Return the current block list.

_Parameters_

-   _state_ `Object`:

_Returns_

-   `Array`: Block list.

### getEditorSelection

Returns the current selection.

_Parameters_

-   _state_ `Object`:

_Returns_

-   `WPBlockSelection`: The selection end.

### getEditorSelectionEnd

> **Deprecated** since Gutenberg 10.0.0.

Returns the current selection end.

_Parameters_

-   _state_ `Object`:

_Returns_

-   `WPBlockSelection`: The selection end.

### getEditorSelectionStart

> **Deprecated** since Gutenberg 10.0.0.

Returns the current selection start.

_Parameters_

-   _state_ `Object`:

_Returns_

-   `WPBlockSelection`: The selection start.

### getEditorSettings

Returns the post editor settings.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `Object`: The editor settings object.

### getFirstMultiSelectedBlockClientId

_Related_

-   getFirstMultiSelectedBlockClientId in core/block-editor store.

### getGlobalBlockCount

_Related_

-   getGlobalBlockCount in core/block-editor store.

### getInserterItems

_Related_

-   getInserterItems in core/block-editor store.

### getLastMultiSelectedBlockClientId

_Related_

-   getLastMultiSelectedBlockClientId in core/block-editor store.

### getMultiSelectedBlockClientIds

_Related_

-   getMultiSelectedBlockClientIds in core/block-editor store.

### getMultiSelectedBlocks

_Related_

-   getMultiSelectedBlocks in core/block-editor store.

### getMultiSelectedBlocksEndClientId

_Related_

-   getMultiSelectedBlocksEndClientId in core/block-editor store.

### getMultiSelectedBlocksStartClientId

_Related_

-   getMultiSelectedBlocksStartClientId in core/block-editor store.

### getNextBlockClientId

_Related_

-   getNextBlockClientId in core/block-editor store.

### getPermalink

Returns the permalink for the post.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `?string`: The permalink, or null if the post is not viewable.

### getPermalinkParts

Returns the permalink for a post, split into it's three parts: the prefix,
the postName, and the suffix.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `Object`: An object containing the prefix, postName, and suffix for the permalink, or null if the post is not viewable.

### getPostEdits

Returns any post values which have been changed in the editor but not yet
been saved.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Object`: Object of key value pairs comprising unsaved edits.

### getPostLockUser

Returns details about the post lock user.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Object`: A user object.

### getPostTypeLabel

Returns a post type label depending on the current post.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `string|undefined`: The post type label if available, otherwise undefined.

### getPreviousBlockClientId

_Related_

-   getPreviousBlockClientId in core/block-editor store.

### getReferenceByDistinctEdits

> **Deprecated** since Gutenberg 6.5.0.

Returns a new reference when edited values have changed. This is useful in
inferring where an edit has been made between states by comparison of the
return values using strict equality.

_Usage_

    const hasEditOccurred = (
       getReferenceByDistinctEdits( beforeState ) !==
       getReferenceByDistinctEdits( afterState )
    );

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `*`: A value whose reference will change only when an edit occurs.

### getSelectedBlock

_Related_

-   getSelectedBlock in core/block-editor store.

### getSelectedBlockClientId

_Related_

-   getSelectedBlockClientId in core/block-editor store.

### getSelectedBlockCount

_Related_

-   getSelectedBlockCount in core/block-editor store.

### getSelectedBlocksInitialCaretPosition

_Related_

-   getSelectedBlocksInitialCaretPosition in core/block-editor store.

### getStateBeforeOptimisticTransaction

> **Deprecated** since Gutenberg 9.7.0.

Returns state object prior to a specified optimist transaction ID, or `null`
if the transaction corresponding to the given ID cannot be found.

### getSuggestedPostFormat

Returns a suggested post format for the current post, inferred only if there
is a single block within the post and it is of a type known to match a
default post format. Returns null if the format cannot be determined.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?string`: Suggested post format.

### getTemplate

_Related_

-   getTemplate in core/block-editor store.

### getTemplateLock

_Related_

-   getTemplateLock in core/block-editor store.

### hasAutosave

> **Deprecated** since 5.6. Callers should use the `getAutosave( postType, postId, userId )` selector from the '@wordpress/core-data' package and check for a truthy value.

Returns the true if there is an existing autosave, otherwise false.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether there is an existing autosave.

### hasChangedContent

Returns true if content includes unsaved changes, or false otherwise.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `boolean`: Whether content includes unsaved changes.

### hasEditorRedo

Returns true if any future editor history snapshots exist, or false
otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether redo history exists.

### hasEditorUndo

Returns true if any past editor history snapshots exist, or false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether undo history exists.

### hasInserterItems

_Related_

-   hasInserterItems in core/block-editor store.

### hasMultiSelection

_Related_

-   hasMultiSelection in core/block-editor store.

### hasNonPostEntityChanges

Returns true if there are unsaved edits for entities other than
the editor's post, and false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether there are edits or not.

### hasSelectedBlock

_Related_

-   hasSelectedBlock in core/block-editor store.

### hasSelectedInnerBlock

_Related_

-   hasSelectedInnerBlock in core/block-editor store.

### inSomeHistory

> **Deprecated** since Gutenberg 9.7.0.

Returns true if an optimistic transaction is pending commit, for which the
before state satisfies the given predicate function.

### isAncestorMultiSelected

_Related_

-   isAncestorMultiSelected in core/block-editor store.

### isAutosavingPost

Returns true if the post is autosaving, or false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the post is autosaving.

### isBlockInsertionPointVisible

_Related_

-   isBlockInsertionPointVisible in core/block-editor store.

### isBlockMultiSelected

_Related_

-   isBlockMultiSelected in core/block-editor store.

### isBlockSelected

_Related_

-   isBlockSelected in core/block-editor store.

### isBlockValid

_Related_

-   isBlockValid in core/block-editor store.

### isBlockWithinSelection

_Related_

-   isBlockWithinSelection in core/block-editor store.

### isCaretWithinFormattedText

_Related_

-   isCaretWithinFormattedText in core/block-editor store.

### isCleanNewPost

Returns true if there are no unsaved values for the current edit session and
if the currently edited post is new (has never been saved before).

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether new post and unsaved values exist.

### isCurrentPostPending

Returns true if post is pending review.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether current post is pending review.

### isCurrentPostPublished

Return true if the current post has already been published.

_Parameters_

-   _state_ `Object`: Global application state.
-   _currentPost_ `Object?`: Explicit current post for bypassing registry selector.

_Returns_

-   `boolean`: Whether the post has been published.

### isCurrentPostScheduled

Returns true if post is already scheduled.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether current post is scheduled to be posted.

### isEditedPostAutosaveable

Returns true if the post can be autosaved, or false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.
-   _autosave_ `Object`: A raw autosave object from the REST API.

_Returns_

-   `boolean`: Whether the post can be autosaved.

### isEditedPostBeingScheduled

Return true if the post being edited is being scheduled. Preferring the
unsaved status values.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the post has been published.

### isEditedPostDateFloating

Returns whether the current post should be considered to have a "floating"
date (i.e. that it would publish "Immediately" rather than at a set time).

Unlike in the PHP backend, the REST API returns a full date string for posts
where the 0000-00-00T00:00:00 placeholder is present in the database. To
infer that a post is set to publish "Immediately" we check whether the date
and modified date are the same.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `boolean`: Whether the edited post has a floating date value.

### isEditedPostDirty

Returns true if there are unsaved values for the current edit session, or
false if the editing state matches the saved or new post.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether unsaved values exist.

### isEditedPostEmpty

Returns true if the edited post has content. A post has content if it has at
least one saveable block or otherwise has a non-empty content property
assigned.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether post has content.

### isEditedPostNew

Returns true if the currently edited post is yet to be saved, or false if
the post has been saved.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the post is new.

### isEditedPostPublishable

Return true if the post being edited can be published.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the post can been published.

### isEditedPostSaveable

Returns true if the post can be saved, or false otherwise. A post must
contain a title, an excerpt, or non-empty content to be valid for save.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the post can be saved.

### isFirstMultiSelectedBlock

_Related_

-   isFirstMultiSelectedBlock in core/block-editor store.

### isMultiSelecting

_Related_

-   isMultiSelecting in core/block-editor store.

### isPermalinkEditable

Returns whether the permalink is editable or not.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `boolean`: Whether or not the permalink is editable.

### isPostAutosavingLocked

Returns whether post autosaving is locked.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Is locked.

### isPostLocked

Returns whether the post is locked.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Is locked.

### isPostLockTakeover

Returns whether the edition of the post has been taken over.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Is post lock takeover.

### isPostSavingLocked

Returns whether post saving is locked.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Is locked.

### isPreviewingPost

Returns true if the post is being previewed, or false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the post is being previewed.

### isPublishingPost

Returns true if the post is being published, or false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether post is being published.

### isPublishSidebarEnabled

Returns whether the pre-publish panel should be shown
or skipped when the user clicks the "publish" button.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the pre-publish panel should be shown or not.

### isSavingNonPostEntityChanges

Returns true if non-post entities are currently being saved, or false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether non-post entities are being saved.

### isSavingPost

Returns true if the post is currently being saved, or false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether post is being saved.

### isSelectionEnabled

_Related_

-   isSelectionEnabled in core/block-editor store.

### isTyping

_Related_

-   isTyping in core/block-editor store.

### isValidTemplate

_Related_

-   isValidTemplate in core/block-editor store.

<!-- END TOKEN(Autogenerated selectors|../../../packages/editor/src/store/selectors.js) -->

## Actions

<!-- START TOKEN(Autogenerated actions|../../../packages/editor/src/store/actions.js) -->

### autosave

Action generator used in signalling that the post should autosave. This
includes server-side autosaving (default) and client-side (a.k.a. local)
autosaving (e.g. on the Web, the post might be committed to Session
Storage).

_Parameters_

-   _options_ `Object?`: Extra flags to identify the autosave.

### clearSelectedBlock

_Related_

-   clearSelectedBlock in core/block-editor store.

### createUndoLevel

Returns an action object used in signalling that undo history record should
be created.

_Returns_

-   `Object`: Action object.

### disablePublishSidebar

Returns an action object used in signalling that the user has disabled the
publish sidebar.

_Returns_

-   `Object`: Action object

### editPost

Returns an action object used in signalling that attributes of the post have
been edited.

_Parameters_

-   _edits_ `Object`: Post attributes to edit.
-   _options_ `Object`: Options for the edit.

### enablePublishSidebar

Returns an action object used in signalling that the user has enabled the
publish sidebar.

_Returns_

-   `Object`: Action object

### enterFormattedText

_Related_

-   enterFormattedText in core/block-editor store.

### exitFormattedText

_Related_

-   exitFormattedText in core/block-editor store.

### hideInsertionPoint

_Related_

-   hideInsertionPoint in core/block-editor store.

### insertBlock

_Related_

-   insertBlock in core/block-editor store.

### insertBlocks

_Related_

-   insertBlocks in core/block-editor store.

### insertDefaultBlock

_Related_

-   insertDefaultBlock in core/block-editor store.

### lockPostAutosaving

Returns an action object used to signal that post autosaving is locked.

_Usage_

    // Lock post autosaving with the lock key `mylock`:
    wp.data.dispatch( 'core/editor' ).lockPostAutosaving( 'mylock' );

_Parameters_

-   _lockName_ `string`: The lock name.

_Returns_

-   `Object`: Action object

### lockPostSaving

Returns an action object used to signal that post saving is locked.

_Usage_

    const { subscribe } = wp.data;

    const initialPostStatus = wp.data.select( 'core/editor' ).getEditedPostAttribute( 'status' );

    // Only allow publishing posts that are set to a future date.
    if ( 'publish' !== initialPostStatus ) {

    	// Track locking.
    	let locked = false;

    	// Watch for the publish event.
    	let unssubscribe = subscribe( () => {
    		const currentPostStatus = wp.data.select( 'core/editor' ).getEditedPostAttribute( 'status' );
    		if ( 'publish' !== currentPostStatus ) {

    			// Compare the post date to the current date, lock the post if the date isn't in the future.
    			const postDate = new Date( wp.data.select( 'core/editor' ).getEditedPostAttribute( 'date' ) );
    			const currentDate = new Date();
    			if ( postDate.getTime() <= currentDate.getTime() ) {
    				if ( ! locked ) {
    					locked = true;
    					wp.data.dispatch( 'core/editor' ).lockPostSaving( 'futurelock' );
    				}
    			} else {
    				if ( locked ) {
    					locked = false;
    					wp.data.dispatch( 'core/editor' ).unlockPostSaving( 'futurelock' );
    				}
    			}
    		}
    	} );
    }

_Parameters_

-   _lockName_ `string`: The lock name.

_Returns_

-   `Object`: Action object

### mergeBlocks

_Related_

-   mergeBlocks in core/block-editor store.

### moveBlocksDown

_Related_

-   moveBlocksDown in core/block-editor store.

### moveBlocksUp

_Related_

-   moveBlocksUp in core/block-editor store.

### moveBlockToPosition

_Related_

-   moveBlockToPosition in core/block-editor store.

### multiSelect

_Related_

-   multiSelect in core/block-editor store.

### receiveBlocks

_Related_

-   receiveBlocks in core/block-editor store.

### redo

Returns an action object used in signalling that undo history should
restore last popped state.

### refreshPost

Action generator for handling refreshing the current post.

### removeBlock

_Related_

-   removeBlock in core/block-editor store.

### removeBlocks

_Related_

-   removeBlocks in core/block-editor store.

### replaceBlock

_Related_

-   replaceBlock in core/block-editor store.

### replaceBlocks

_Related_

-   replaceBlocks in core/block-editor store.

### resetAutosave

> **Deprecated** since 5.6. Callers should use the `receiveAutosaves( postId, autosave )` selector from the '@wordpress/core-data' package.

Returns an action object used in signalling that the latest autosave of the
post has been received, by initialization or autosave.

_Parameters_

-   _newAutosave_ `Object`: Autosave post object.

_Returns_

-   `Object`: Action object.

### resetBlocks

_Related_

-   resetBlocks in core/block-editor store.

### resetEditorBlocks

Returns an action object used to signal that the blocks have been updated.

_Parameters_

-   _blocks_ `Array`: Block Array.
-   _options_ `?Object`: Optional options.

### resetPost

Returns an action object used in signalling that the latest version of the
post has been received, either by initialization or save.

_Parameters_

-   _post_ `Object`: Post object.

_Returns_

-   `Object`: Action object.

### savePost

Action generator for saving the current post in the editor.

_Parameters_

-   _options_ `Object`:

### selectBlock

_Related_

-   selectBlock in core/block-editor store.

### setTemplateValidity

_Related_

-   setTemplateValidity in core/block-editor store.

### setupEditor

Returns an action generator used in signalling that editor has initialized with
the specified post object and editor settings.

_Parameters_

-   _post_ `Object`: Post object.
-   _edits_ `Object`: Initial edited attributes object.
-   _template_ `Array?`: Block Template.

### setupEditorState

Returns an action object used to setup the editor state when first opening
an editor.

_Parameters_

-   _post_ `Object`: Post object.

_Returns_

-   `Object`: Action object.

### showInsertionPoint

_Related_

-   showInsertionPoint in core/block-editor store.

### startMultiSelect

_Related_

-   startMultiSelect in core/block-editor store.

### startTyping

_Related_

-   startTyping in core/block-editor store.

### stopMultiSelect

_Related_

-   stopMultiSelect in core/block-editor store.

### stopTyping

_Related_

-   stopTyping in core/block-editor store.

### synchronizeTemplate

_Related_

-   synchronizeTemplate in core/block-editor store.

### toggleBlockMode

_Related_

-   toggleBlockMode in core/block-editor store.

### toggleSelection

_Related_

-   toggleSelection in core/block-editor store.

### trashPost

Action generator for trashing the current post in the editor.

### undo

Returns an action object used in signalling that undo history should pop.

### unlockPostAutosaving

Returns an action object used to signal that post autosaving is unlocked.

_Usage_

    // Unlock post saving with the lock key `mylock`:
    wp.data.dispatch( 'core/editor' ).unlockPostAutosaving( 'mylock' );

_Parameters_

-   _lockName_ `string`: The lock name.

_Returns_

-   `Object`: Action object

### unlockPostSaving

Returns an action object used to signal that post saving is unlocked.

_Usage_

    // Unlock post saving with the lock key `mylock`:
    wp.data.dispatch( 'core/editor' ).unlockPostSaving( 'mylock' );

_Parameters_

-   _lockName_ `string`: The lock name.

_Returns_

-   `Object`: Action object

### updateBlock

_Related_

-   updateBlock in core/block-editor store.

### updateBlockAttributes

_Related_

-   updateBlockAttributes in core/block-editor store.

### updateBlockListSettings

_Related_

-   updateBlockListSettings in core/block-editor store.

### updateEditorSettings

Undocumented declaration.

### updatePost

> **Deprecated** since Gutenberg 9.7.0.

Returns an action object used in signalling that a patch of updates for the
latest version of the post have been received.

_Returns_

-   `Object`: Action object.

### updatePostLock

Returns an action object used to lock the editor.

_Parameters_

-   _lock_ `Object`: Details about the post lock status, user, and nonce.

_Returns_

-   `Object`: Action object.

<!-- END TOKEN(Autogenerated actions|../../../packages/editor/src/store/actions.js) -->
